/****************************************************************************
 * Copyright (C) from 2009 to Present EPAM Systems.
 *
 * This file is part of Indigo toolkit.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ***************************************************************************/

package com.epam.indigo;

import com.sun.jna.Library;
import com.sun.jna.Pointer;

public interface IndigoInchiLib extends Library {
    Pointer indigoInchiVersion();

    int indigoInchiResetOptions();

    int indigoInchiLoadMolecule(String inchi_string);

    Pointer indigoInchiGetInchi(int molecule);

    Pointer indigoInchiGetInchiKey(String inchi_string);

    Pointer indigoInchiGetWarning();

    Pointer indigoInchiGetLog();

    Pointer indigoInchiGetAuxInfo();
}
